aboutsummaryrefslogtreecommitdiffstats
path: root/src/amd/common/ac_llvm_build.h
diff options
context:
space:
mode:
authorMarek Olšák <[email protected]>2018-09-07 18:44:54 -0400
committerMarek Olšák <[email protected]>2018-10-06 21:50:09 -0400
commita668c8d6ba981b3439fad0d07ce7a22b5a49b967 (patch)
tree9eb722428f56a248b3beb437936e83fd0d909b21 /src/amd/common/ac_llvm_build.h
parent8f77156c268356baf9df8490c52cc5d8475b9db8 (diff)
ac: define all address spaces properly
Diffstat (limited to 'src/amd/common/ac_llvm_build.h')
-rw-r--r--src/amd/common/ac_llvm_build.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/amd/common/ac_llvm_build.h b/src/amd/common/ac_llvm_build.h
index 0df9234c664..73f8a6b70cd 100644
--- a/src/amd/common/ac_llvm_build.h
+++ b/src/amd/common/ac_llvm_build.h
@@ -37,10 +37,12 @@ extern "C" {
#define HAVE_32BIT_POINTERS (HAVE_LLVM >= 0x0700)
enum {
- /* CONST is the only address space that selects SMEM loads */
- AC_CONST_ADDR_SPACE = HAVE_LLVM >= 0x700 ? 4 : 2,
- AC_LOCAL_ADDR_SPACE = 3,
- AC_CONST_32BIT_ADDR_SPACE = 6, /* same as CONST, but the pointer type has 32 bits */
+ AC_ADDR_SPACE_FLAT = HAVE_LLVM >= 0x0700 ? 0 : 4, /* Slower than global. */
+ AC_ADDR_SPACE_GLOBAL = 1,
+ AC_ADDR_SPACE_GDS = HAVE_LLVM >= 0x0700 ? 2 : 5,
+ AC_ADDR_SPACE_LDS = 3,
+ AC_ADDR_SPACE_CONST = HAVE_LLVM >= 0x0700 ? 4 : 2, /* Global allowing SMEM. */
+ AC_ADDR_SPACE_CONST_32BIT = 6, /* same as CONST, but the pointer type has 32 bits */
};
/* Combine these with & instead of |. */